@@ -8,11 +8,11 @@ import pathlib
 from abc import ABC, abstractmethod
 from datetime import datetime
 from types import TracebackType
-from typing import Any, Callable, Dict, Optional, Set, Tuple, Type, cast
+from typing import Any, Callable, Dict, Literal, Optional, Set, Tuple, Type, cast
 
-from pkg_resources import iter_entry_points
-from typing_extensions import Literal
+from typing_extensions import Self
 
+from .._entry_points import read_entry_points
 from ..listener import Listener
 from ..message import Message
 from ..typechecking import AcceptedIOType, FileLike, StringPathLike
@@ -20,7 +20,12 @@ from .asc import ASCWriter
 from .blf import BLFWriter
 from .canutils import CanutilsLogWriter
 from .csv import CSVWriter
-from .generic import BaseIOHandler, FileIOMessageWriter, MessageWriter
+from .generic import (
+    BaseIOHandler,
+    BinaryIOMessageWriter,
+    FileIOMessageWriter,
+    MessageWriter,
+)
 from .mf4 import MF4Writer
 from .printer import Printer
 from .sqlite import SqliteWriter
@@ -84,8 +89,8 @@ class Logger(MessageWriter):
         if not Logger.fetched_plugins:
             Logger.message_writers.update(
                 {
-                    writer.name: writer.load()
-                    for writer in iter_entry_points("can.io.message_writer")
+                    writer.key: cast(Type[MessageWriter], writer.load())
+                    for writer in read_entry_points("can.io.message_writer")
                 }
             )
             Logger.fetched_plugins = True
@@ -94,20 +99,28 @@ class Logger(MessageWriter):
 
         file_or_filename: AcceptedIOType = filename
         if suffix == ".gz":
-            suffix, file_or_filename = Logger.compress(filename, **kwargs)
+            logger_type, file_or_filename = Logger.compress(filename, **kwargs)
+        else:
+            logger_type = cls._get_logger_for_suffix(suffix)
 
+        return logger_type(file=file_or_filename, **kwargs)
+
+    @classmethod
+    def _get_logger_for_suffix(cls, suffix: str) -> Type[MessageWriter]:
         try:
-            LoggerType = Logger.message_writers[suffix]
-            if LoggerType is None:
+            logger_type = Logger.message_writers[suffix]
+            if logger_type is None:
                 raise ValueError(f'failed to import logger for extension "{suffix}"')
-            return LoggerType(file=file_or_filename, **kwargs)
+            return logger_type
         except KeyError:
             raise ValueError(
                 f'No write support for this unknown log format "{suffix}"'
             ) from None
 
-    @staticmethod
-    def compress(filename: StringPathLike, **kwargs: Any) -> Tuple[str, FileLike]:
+    @classmethod
+    def compress(
+        cls, filename: StringPathLike, **kwargs: Any
+    ) -> Tuple[Type[MessageWriter], FileLike]:
         """
         Return the suffix and io object of the decompressed file.
         File will automatically recompress upon close.
@@ -117,12 +130,15 @@ class Logger(MessageWriter):
             raise ValueError(
                 f"The file type {real_suffix} is currently incompatible with gzip."
             )
-        if kwargs.get("append", False):
-            mode = "ab" if real_suffix == ".blf" else "at"
-        else:
-            mode = "wb" if real_suffix == ".blf" else "wt"
+        logger_type = cls._get_logger_for_suffix(real_suffix)
+        append = kwargs.get("append", False)
 
-        return real_suffix, gzip.open(filename, mode)
+        if issubclass(logger_type, BinaryIOMessageWriter):
+            mode = "ab" if append else "wb"
+        else:
+            mode = "at" if append else "wt"
+
+        return logger_type, gzip.open(filename, mode)
 
     def on_message_received(self, msg: Message) -> None:
         pass
@@ -259,7 +275,7 @@ class BaseRotatingLogger(Listener, BaseIOHandler, ABC):
         """
         self.writer.stop()
 
-    def __enter__(self) -> "BaseRotatingLogger":
+    def __enter__(self) -> Self:
         return self
 
     def __exit__(
